%define name grass
%define ver 5.0.2
%define rel 1mdk

Summary: 	Geographic Resources Analysis Support System
Name: 		%name
Version: 	%ver
Release: 	%rel
Group: 		Sciences/Geosciences
License: 	GPL
URL: 		http://grass.itc.it/
Source: 	http://grass.itc.it/grass5/source/%{name}-%{version}_src.tar.bz2
Source1: 	grass5_48.png.bz2
Source2: 	grass5_32.png.bz2
Source3: 	grass5_16.png.bz2
Patch0:  	grass5_pre5_makefile_destdir.patch.bz2
Patch1:		grass-5.0.x-tcl-8.4-hack.patch.bz2
BuildRoot: 	%{_tmppath}/%{name}-%{version}-root
Requires:	xterm
BuildRequires: 	libpng-devel
BuildRequires: 	libjpeg-devel
BuildRequires: 	libtiff-devel
BuildRequires: 	libgd2-devel
BuildRequires: 	freetype2-devel
BuildRequires: 	libMesaGLU-devel libunixODBC-devel fftw-devel
BuildRequires: 	lesstif-devel
BuildRequires: 	tk
BuildRequires: 	libncurses-devel
BuildRequires: 	zlib-devel
BuildRequires:	gdbm-devel
BuildRequires:	readline-devel
BuildRequires:	gcc-g77
BuildRequires:	liblapack-devel
BuildRequires:	libgdal-devel
BuildRequires:	libblas-devel
BuildRequires:	flex
BuildRequires:	bison

%description
GRASS (Geographic Resources Analysis Support System)
is a raster-based GIS, vector GIS,
image processing system, graphics production
system, data management system, and spatial
modeling system. A graphical user interface
for X-Windows is provided.


%prep
%setup -q -n %{name}%{version}
%patch0 -p1
%if %(echo `rpm -q --qf %{VERSION} tcl `|awk '{if ($1>=8.4) print 1; else print 0}')
%patch1 -p1
%endif

%build
%configure \
	--with-dbm-includes=%{_includedir}/gdbm/ \
	--with-postgres-includes='%{_includedir}/pgsql %{_includedir}/pgsql/internal' \
	--with-nls \
	--with-blas \
	--with-lapack \
	--with-freetype \
	--with-freetype-includes=%{_includedir}/freetype2/ \
	--with-motif \
	--with-motif-includes=%{_prefix}/X11R6/include \
	--with-dbm \
	--with-glw \
	--with-gdal
#	--with-readline \
#Fix messy grass readline misdetection:
perl -pi -e "s/^READLINELIB .*\$/READLINELIB         =  -lreadline -ltermcap/g" src/CMD/head/head
perl -pi -e "s/^HISTORYLIB.*\$/HISTORYLIB          =  -lhistory/g" src/CMD/head/head
perl -pi -e 's,/\* #undef HAVE_READLINE_READLINE_H \*/,#define HAVE_READLINE_READLINE_H 1,g' src/include/config.h
make

%install
RPM_BUILD_PATH=$RPM_BUILD_DIR/%{name}%{ver}
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf "$RPM_BUILD_ROOT"
mkdir -p $RPM_BUILD_ROOT/%{_bindir}
mkdir -p $RPM_BUILD_ROOT/%{_menudir}
%makeinstall_std INST_DIR=%{_libdir}/grass5
# Actions in make install that don't take into account packaging in a place different to running:
#	sed -e 's|^GISBASE.*|GISBASE=%{_prefix}/lib/grass5|' \
#	$RPM_BUILD_PATH/bin.i586-mandrake-linux-gnu/grass5 \
#	> $RPM_BUILD_ROOT/%{_bindir}/grass5
#chmod a+x $RPM_BUILD_ROOT/usr/bin/grass5
#cp $RPM_BUILD_PATH/bin.i586-mandrake-linux-gnu/gmake5 $RPM_BUILD_ROOT/usr/bin
#cp $RPM_BUILD_PATH/bin.i586-mandrake-linux-gnu/gmakelinks5 $RPM_BUILD_ROOT/usr/bin

# Manually bzip2 the man pages:
bzip2 $RPM_BUILD_ROOT/%{_libdir}/grass5/man/man?/*

#Get rid of lock dir for hostname:
rmdir $RPM_BUILD_ROOT/%{_libdir}/grass5/locks/`hostname`

#Menu support:
cat << EOF > $RPM_BUILD_ROOT/%{_menudir}/%{name}
?package(%{name}):command="%{_bindir}/grass5" \
icon="%{name}.png" \
needs="text" \
section="Applications/Sciences/Geosciences" \
title="Grass" \
longtitle="Geographic Resources Analysis Support System"
EOF

mkdir -p $RPM_BUILD_ROOT%{_liconsdir} $RPM_BUILD_ROOT%{_iconsdir} $RPM_BUILD_ROOT%{_miconsdir}

bzcat %{SOURCE1} > $RPM_BUILD_ROOT%{_liconsdir}/%{name}.png
bzcat %{SOURCE2} > $RPM_BUILD_ROOT%{_iconsdir}/%{name}.png
bzcat %{SOURCE3} > $RPM_BUILD_ROOT%{_miconsdir}/%{name}.png

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf "$RPM_BUILD_ROOT"

%post
%update_menus

%postun
%clean_menus

%files
%defattr(-,root,root)
%attr(0755,root,root) %{_bindir}/*
%{_libdir}/grass5/
%lang(ru) %{_libdir}/grass5/locale/ru/LC_MESSAGES/
%{_menudir}/%{name}
%{_miconsdir}/*.png
%{_liconsdir}/*.png
%{_iconsdir}/*.png
%attr(1777,root,root) %{_libdir}/grass5/locks
%doc AUTHORS BUGS COPYING INSTALL NEWS.html ONGOING README ChangeLog
%doc REQUIREMENTS.html SUBMITTING TODO.txt

%changelog
* Fri Apr 11 2003 Buchan Milne <bgmilne@linux-mandrake.com> 5.0.2-1mdk
- 5.0.2
- Rebuild for tcl8.4
- Misc fixes (incl xpm->png)
- try and fix misdetection of readline
- Hack for tcl 8.4/nviz, may be broken, will find out on Sunday ...
- Buildrequires flex and bison (the value of a clean install ;-))

* Sat Feb 22 2003 Buchan Milne <bgmilne@linux-mandrake.com> 5.0.0-3mdk
- Require xterm

* Fri Feb 21 2003 Buchan Milne <bgmilne@linux-mandrake.com> 5.0.0-2mdk
- Buildrequire libblas-devel
- Rebuild for postgres

* Wed Sep 04 2002 Buchan Milne <bgmilne@linux-mandrake.com> 5.0.0-1mdk
- 5.0.0
- buildrequire libgd2-devel (24bit PNG driver)

* Sun Aug 18 2002 Buchan Milne <bgmilne@linux-mandrake.com> 5.0.0-0.pre5.3mdk
- Add back gdal, lapack and blas support (aka I build too seldom on klama!).

* Fri Aug 16 2002 Buchan Milne <bgmilne@linux-mandrake.com> 5.0.0-0.pre5.2mdk
- build with dbmi, glw and readline support
- require gcc-g77 for lapack and blas
- gdal,lapack,blas support optional (klama frozen :-().

* Mon Aug 05 2002 Buchan Milne <bgmilne@linux-mandrake.com> 5.0.0-0.pre5.1mdk
- Rebuild
- Buildrequires gdbm, lapack

* Tue Jun 25 2002 Buchan Milne <bgmilne@cae.co.za> 5.0.0-0.pre5.0mdk
- pre5

* Tue May 14 2002 Buchan Milne <bgmilne@cae.co.za> 5.0.0-0.pre4.0mdk
- New prerelase
- PostgreSQL,lapack,gdal support
- Next stop, subpackages

* Mon Apr 14 2002 Buchan Milne <bgmilne@cae.co.za>  5.0.0-0.pre3.0mdk
- First stab at a Mandrake RPM
- No postgres support (doesn't build against 7.2 but does against 7.1)
- Probably need subpackages for nvis, tcltkgrass, odbc, postgres etc
